#include <eZ8.h>

#define DATA_DIR	0x01	/*Define indirect address for data direction.*/
#define ALT_FUN		0x02	/*Define indirect address for alternate function.*/
#define OUT_CTL		0x03	/*Define indirect address for output control.*/
#define HDR_EN		0x04	/*Define indirect address for high current output.*/
#define SMRS_EN		0x05	/*Define indirect address for stop mode recovery.*/
#define SAVE_PORT	0x00	/*Define address for inadvertently changes.*/

void init_gpio(void)
{

PAADDR	= ALT_FUN;		/*Select Port A function register.                                            */
PACTL	= 0x00;			/*Port A all data-I/O-lines. Other alternatives (Selected by "1":             */
						/*PA0 - T0IN (Timer 0 Input.)                                                 */
						/*PA1 - T0OUT (Timer 0 Output.)                                               */
						/*PA2 - N/A (No alternate function.)                                          */
						/*PA3 - nCTS0 (UART 0 Clear To Send.)                                         */
						/*PA4 - RXD0 / IRRX0 (UART 0 / IrDA 0 Receive Data.)                          */
						/*PA5 - TXD0 / IRTX0 (UART 0 / IrDA 0 Transmit Data.)                         */
						/*PA6 - SCL (I2C Clock [Automacically Open-Drain].)                           */
						/*PA7 - SDA (I2C Data (Automatically Open-Drain].)                            */
PAADDR	= DATA_DIR;		/*Select Port A data direction register.                                      */
PACTL	= 0x00;			/*Port A0-A7 all outputs (switches).                                          */
						/*Select "1" for input direction of each pin.                                 */
PAADDR	= OUT_CTL;		/*Select Port A output control register.                                      */
PACTL	= 0x00;			/*Port A all normal outputs, not open-drain.                                  */
						/*Select "1" for open-drain function of each pin.                             */
PAADDR	= HDR_EN;		/*Select Port A high drive enable register.                                   */
PACTL	= 0xff;			/*Port A0-A7 have high-current drive capability now.                          */
						/*Select "1" for high-drive capability of each pin.                           */
PAADDR	= SMRS_EN;		/*Select Port A's register for stop-mode-recovery.                            */
PACTL	= 0x00;			/*Port A can't initiate a stop-mode-recovery.                                 */
						/*Select "1" for stop-mode-recovery capability of each pin.                   */
PAADDR	= SAVE_PORT;	/*Save Port A against changes.                                                */

PBADDR	= ALT_FUN;		/*Select Port B function register.*/
PBCTL	= 0x00;			/*Port B all data-I/O-lines (other alternatives: ADC.*/
PBADDR	= DATA_DIR;		/*Select Port B data direction register.*/
PBCTL	= 0x00;			/*Port B0-B7 all outputs (switches).*/
PBADDR	= OUT_CTL;		/*Select Port B output control register.*/
PBCTL	= 0x00;			/*Port B all normal outputs, not open-drain.*/
PBADDR	= HDR_EN;		/*Select Port B high drive enable register.*/
PBCTL	= 0xff;			/*Port B0-B7 have high-current drive capability now.*/
PBADDR	= SMRS_EN;		/*Select Port B's register for stop-mode-recovery.*/
PBCTL	= 0x00;			/*Port B can't initiate a stop-mode-recovery.*/
PBADDR	= SAVE_PORT;	/*Save Port B against changes.*/

PCADDR	= ALT_FUN;		/*Select Port C function register.*/
PCCTL	= 0x00;			/*Port C all data-I/O-lines. Other alternatives:                              */
						/*PC0 - T1IN (Timer 1 Input).                                                 */
						/*PC1 - T1OUT (Timer 1 Output).                                               */
						/*PC2 - nSS (SPI Slave Select).                                               */
						/*PC3 - SCK (SPI Serial Clock).                                               */
						/*PC4 - MOSI (SPI Master Out Slave In).                                       */
						/*PC5 - MISO (SPI Master In Slave Out).                                       */
						/*PC6 - T2IN (Timer 2 In).                                                    */
						/*PC7 - T2OUT (Timer 2 Out).                                                  */
PCADDR	= DATA_DIR;		/*Select Port C data direction register.*/
PCCTL	= 0x00;			/*Port C0-C7 all outputs.*/
PCADDR	= OUT_CTL;		/*Select Port C output control register.*/
PCCTL	= 0x00;			/*Port C all normal inputs, not open-drain.*/
PCADDR	= HDR_EN;		/*Select Port C high drive enable register.*/
PCCTL	= 0xff;			/*Port C0-C7 have high-current drive capability now.*/	
PCADDR	= SMRS_EN;		/*Select Port C's register for stop-mode-recovery.*/
PCCTL	= 0x00;			/*Port C can't initiate a stop-mode-recovery.*/
PCADDR	= SAVE_PORT;	/*Save Port C against changes.*/

PDADDR	= ALT_FUN;		/*Select Port D function register.*/
PDCTL	= 0x00;			/*Port D all data-I/O-lines. Other alternatives:                             */
						/*PD0 - T3IN (Timer 3 In, not available in 40- & 44-pin packages.            */
						/*PD1 - T3OUT (Timer 3 Out, not available in 40- & 44-pin packages.          */
						/*PD2 - N/A (No alternate function).                                         */
						/*PD3 - N/A (No alternate function).                                         */
						/*PD4 - RXD1 / IRRX1 (UART 1 / IrDA 1 Receive Data).                         */
						/*PD5 - TXD1 / IRTX1 (UART 1 / IrDA 1 Transmit Data).                        */
						/*PD6 - nCTS1 (UART 1 Clear to Send).                                        */
						/*PD7 - RCOUT (Watch-Dog Timer RC Oscillator Output).                        */
PDADDR	= DATA_DIR;		/*Select Port D data direction register.*/
PDCTL	= 0x80;			/*Port D0-D3 all inputs (switches), D4-D6 outputs (LEDs). D7 doesn't exist.*/
PDADDR	= OUT_CTL;		/*Select Port D output control register.*/
PDCTL	= 0x00;			/*Port D all normal inputs, not open-drain.*/
PDADDR	= HDR_EN;		/*Select Port D high drive enable register.*/
PDCTL	= 0xff;			/*Port D4-D7 have high drive capability now. D7 doesn't exist.*/
PDADDR	= SMRS_EN;		/*Select Port D's register for stop-mode-recovery.*/
PDCTL	= 0x00;			/*Port D can't initiate a stop-mode-recovery.*/
PDADDR	= SAVE_PORT;	/*Save Port D against changes.*/

PEADDR	= ALT_FUN;		/*Select Port E function register.*/
PECTL	= 0x00;			/*Port E all data-I/O-lines. Other alternatives:                             */
						/*PD0 - T3IN (Timer 3 In, not available in 40- & 44-pin packages.            */
						/*PD1 - T3OUT (Timer 3 Out, not available in 40- & 44-pin packages.          */
						/*PD2 - N/A (No alternate function).                                         */
						/*PD3 - N/A (No alternate function).                                         */
						/*PD4 - RXD1 / IRRX1 (UART 1 / IrDA 1 Receive Data).                         */
						/*PD5 - TXD1 / IRTX1 (UART 1 / IrDA 1 Transmit Data).                        */
						/*PD6 - nCTS1 (UART 1 Clear to Send).                                        */
						/*PD7 - RCOUT (Watch-Dog Timer RC Oscillator Output).                        */
PEADDR	= DATA_DIR;		/*Select Port E data direction register.*/
PECTL	= 0x00;			/*Port D0-D3 all inputs (switches), D4-D6 outputs (LEDs). D7 doesn't exist.*/
PEADDR	= OUT_CTL;		/*Select Port D output control register.*/
PECTL	= 0xff;			/*Port E all open-drain, not normal inputs.*/
PEADDR	= HDR_EN;		/*Select Port D high drive enable register.*/
PECTL	= 0xff;			/*Port D4-D7 have high drive capability now. D7 doesn't exist.*/
PEADDR	= SMRS_EN;		/*Select Port D's register for stop-mode-recovery.*/
PECTL	= 0x00;			/*Port D can't initiate a stop-mode-recovery.*/
PEADDR	= SAVE_PORT;	/*Save Port D against changes.*/

PFADDR	= ALT_FUN;		/*Select Port F function register.                                            */
PFCTL	= 0x00;			/*Port F all data-I/O-lines. Other alternatives (Selected by "1":             */
						/*PA0 - T0IN (Timer 0 Input.)                                                 */
						/*PA1 - T0OUT (Timer 0 Output.)                                               */
						/*PA2 - N/A (No alternate function.)                                          */
						/*PA3 - nCTS0 (UART 0 Clear To Send.)                                         */
						/*PA4 - RXD0 / IRRX0 (UART 0 / IrDA 0 Receive Data.)                          */
						/*PA5 - TXD0 / IRTX0 (UART 0 / IrDA 0 Transmit Data.)                         */
						/*PA6 - SCL (I2C Clock [Automacically Open-Drain].)                           */
						/*PA7 - SDA (I2C Data (Automatically Open-Drain].)                            */
PFADDR	= DATA_DIR;		/*Select Port F data direction register.                                      */
PFCTL	= 0x00;			/*Port F0-F7 all inputs).                                                     */
						/*Select "1" for input direction of each pin.                                 */
PFADDR	= OUT_CTL;		/*Select Port F output control register.                                      */
PFCTL	= 0x00;			/*Port F all open-drain.                                                      */
						/*Select "1" for open-drain function of each pin.                             */
PFADDR	= HDR_EN;		/*Select Port F high drive enable register.                                   */
PFCTL	= 0xff;			/*Port F0-F7 have high-current drive capability now.                          */
						/*Select "1" for high-drive capability of each pin.                           */
PFADDR	= SMRS_EN;		/*Select Port F's register for stop-mode-recovery.                            */
PFCTL	= 0x00;			/*Port F can't initiate a stop-mode-recovery.                                 */
						/*Select "1" for stop-mode-recovery capability of each pin.                   */
PFADDR	= SAVE_PORT;	/*Save Port F against changes.                                                */

PGADDR	= ALT_FUN;		/*Select Port A function register.                                            */
PGCTL	= 0x00;			/*Port A all data-I/O-lines. Other alternatives (Selected by "1":             */
						/*PA0 - T0IN (Timer 0 Input.)                                                 */
						/*PA1 - T0OUT (Timer 0 Output.)                                               */
						/*PA2 - N/A (No alternate function.)                                          */
						/*PA3 - nCTS0 (UART 0 Clear To Send.)                                         */
						/*PA4 - RXD0 / IRRX0 (UART 0 / IrDA 0 Receive Data.)                          */
						/*PA5 - TXD0 / IRTX0 (UART 0 / IrDA 0 Transmit Data.)                         */
						/*PA6 - SCL (I2C Clock [Automacically Open-Drain].)                           */
						/*PA7 - SDA (I2C Data (Automatically Open-Drain].)                            */
PGADDR	= DATA_DIR;		/*Select Port A data direction register.                                      */
PGCTL	= 0xff;			/*Port A0-A7 all inputs.                                                      */
						/*Select "1" for input direction of each pin.                                 */
PGADDR	= OUT_CTL;		/*Select Port A output control register.                                      */
PGCTL	= 0xff;			/*Port A all open-drain.                                                      */
						/*Select "1" for open-drain function of each pin.                             */
PGADDR	= HDR_EN;		/*Select Port A high drive enable register.                                   */
PGCTL	= 0x00;			/*Port A0-A7 do not have high-current drive capability now.                   */
						/*Select "1" for high-drive capability of each pin.                           */
PGADDR	= SMRS_EN;		/*Select Port A's register for stop-mode-recovery.                            */
PGCTL	= 0x00;			/*Port A can't initiate a stop-mode-recovery.                                 */
						/*Select "1" for stop-mode-recovery capability of each pin.                   */
PGADDR	= SAVE_PORT;	/*Save Port A against changes.                                                */

PHADDR	= ALT_FUN;		/*Select Port E function register.*/
PHCTL	= 0x00;			/*Port E all data-I/O-lines. Other alternatives:                             */
						/*PD0 - T3IN (Timer 3 In, not available in 40- & 44-pin packages.            */
						/*PD1 - T3OUT (Timer 3 Out, not available in 40- & 44-pin packages.          */
						/*PD2 - N/A (No alternate function).                                         */
						/*PD3 - N/A (No alternate function).                                         */
						/*PD4 - RXD1 / IRRX1 (UART 1 / IrDA 1 Receive Data).                         */
						/*PD5 - TXD1 / IRTX1 (UART 1 / IrDA 1 Transmit Data).                        */
						/*PD6 - nCTS1 (UART 1 Clear to Send).                                        */
						/*PD7 - RCOUT (Watch-Dog Timer RC Oscillator Output).                        */
PHADDR	= DATA_DIR;		/*Select Port E data direction register.*/
PHCTL	= 0x00;			/*Port D0-D3 all inputs (switches), D4-D6 outputs (LEDs). D7 doesn't exist.*/
PHADDR	= OUT_CTL;		/*Select Port D output control register.*/
PHCTL	= 0xff;			/*Port E all open-drain, not normal inputs.*/
PHADDR	= HDR_EN;		/*Select Port D high drive enable register.*/
PHCTL	= 0xff;			/*Port D4-D7 have high drive capability now. D7 doesn't exist.*/
PHADDR	= SMRS_EN;		/*Select Port D's register for stop-mode-recovery.*/
PHCTL	= 0x00;			/*Port D can't initiate a stop-mode-recovery.*/
PHADDR	= SAVE_PORT;	/*Save Port D against changes.*/

/*Ports F - G no alternate functions.*/
/*Port H - alternate functions are ADC.*/
}
